@@ -1,6 +1,7 @@
 from fusil.project_agent import ProjectAgent
 from errno import EBADF
 from fusil.score import scoreLogFunc
+from fusil.tools import makeFilename
 from os.path import basename
 from time import time
 import re
@@ -20,6 +21,8 @@ class FileWatch(ProjectAgent):
         self.ignore = []
         self.start = start
         self.regexs = []
+        self.compiled_patterns = None
+        self._need_compile = True
         # Minimum number of lines:
         # eg. (10, -0.2) to add -20% to score if there is fewer than 10 lines
         self.min_nb_line = None
@@ -31,6 +34,8 @@ class FileWatch(ProjectAgent):
         self.read_size = 4096
         self.cleanup_func = None
         self.max_process_time = 0.250   # second
+        # FIXME: write methods instead of direct access to self.words
+        # to be able to update self._need_compile
         self.words = {
             # Notice and warning
             u"too large": 0.10,
@@ -80,6 +85,7 @@ class FileWatch(ProjectAgent):
             regex = regex.encode("ASCII")
         match = re.compile(regex, flags).search
         self.regexs.append((regex, score, match))
+        self._need_compile = True
 
     def compilePatterns(self):
         for text, score, match in self.regexs:
@@ -104,7 +110,9 @@ class FileWatch(ProjectAgent):
         self.total_line = 0
         self.nb_line = 0
         self.score = 0
-        self.compiled_patterns = list(self.compilePatterns())
+        if (self.compiled_patterns is None) or self._need_compile:
+            self._need_compile = False
+            self.compiled_patterns = list(self.compilePatterns())
         self.buffer = []
         if self.file_obj:
             self.prepareFile()
@@ -181,6 +189,8 @@ class FileWatch(ProjectAgent):
         log("Match pattern %r (score %.1f%%) in %r" % (
             pattern, score*100, line))
         self.score += score
+        name = makeFilename(pattern)
+        self.send('session_rename', name)
 
     def readlines(self):
         try:
