@@ -277,6 +277,9 @@ class WriteReplayScript(WriteCode):
         self.write(0, u'execvpe(gdb_arguments[0], gdb_arguments, gdb_env)')
 
     def runCommand(self):
+        self.write(0, u"global null_stdin")
+        self.emptyLine()
+
         self.write(0, u'if options.environ:')
         self.write(1, u'env = environ')
         self.write(1, u'env.update(program_env)')
@@ -300,6 +303,7 @@ class WriteReplayScript(WriteCode):
         self.emptyLine()
         self.write(1, u'program = locateProgram(ptrace_program, raise_error=True)')
         self.write(1, u"arguments = [executable, program, '--'] + arguments")
+        self.write(1, u"null_stdin = False")
         self.emptyLine()
 
         self.write(0, u'if null_stdin:')
