@@ -120,7 +120,8 @@ def runCommand(logger, command, stdin=False, stdout=True, options=None):
     elif stdout is not True:
         options['stdout'] = stdout
         options['stderr'] = STDOUT
-    if 'close_fds' not in options:
+    if ('close_fds' not in options) \
+    and (not RUNNING_WINDOWS):
         options['close_fds'] = True
 
     process = Popen(command, **options)
