@@ -1,4 +1,5 @@
 from itertools import izip
+import re
 
 def minmax(min_value, value, max_value):
     """
@@ -45,3 +46,14 @@ def makeUnicode(text):
         pass
     return unicode(text, "ISO-8859-1")
 
+def makeFilename(text):
+    """
+    >>> makeFilename('Fatal error!')
+    'fatal_error'
+    """
+    text = text.lower()
+    text = re.sub('[^a-z_-]', '_', text)
+    text = re.sub('_{2,}', '_', text)
+    text = re.sub('_$', '', text)
+    return text
+
